ContractId

Struct ContractId 

pub struct ContractId(/* private fields */);
ID to identify the wasm contracts after they have been deployed

Implementations

Source

impl ContractId

pub const fn from_bytes(bytes: [u8; 32]) -> ContractId

Creates a new ContractId from an array of bytes

pub const fn to_bytes(self) -> [u8; 32]

Returns the array of bytes that make up the ContractId

pub fn as_bytes(&self) -> &[u8]

Returns a reference to the array of bytes that make up the ContractId

pub fn as_bytes_mut(&mut self) -> &mut [u8]

Returns a mutable reference to the array of bytes that make up the ContractId