pub enum TxPreconditionError {
DeployLowPrice(u64),
DeployChargeOverflow,
DeployLowLimit(u64),
BlobChargeOverflow,
BlobLowLimit(u64),
BlobEmpty,
BlobTooMany(usize),
PhoenixFeeOverflow,
PhoenixFeeTampered,
PhoenixFeeRefundMismatch,
}Expand description
Error type for checking transaction conditions.
This error is used to indicate that a transaction does not meet the minimum requirements for deployment or blob gas charges.
Variants
DeployLowPrice(u64)
The gas price is too low to deploy a transaction.
DeployChargeOverflow
The deployment charge overflows while calculating the required gas.
DeployLowLimit(u64)
The gas limit is too low to deploy a transaction.
BlobChargeOverflow
The blob charge overflows while calculating the required gas.
BlobLowLimit(u64)
The gas limit is too low to cover the blob gas charges.
BlobEmpty
No blob attached to the transaction.
BlobTooMany(usize)
Too many blobs attached to the transaction.
PhoenixFeeOverflow
Phoenix fee overflow.
PhoenixFeeTampered
Phoenix fee tampered.
PhoenixFeeRefundMismatch
Phoenix fee refund stealth address does not match the proven change note.
Implementations
Sourceimpl TxPreconditionError
impl TxPreconditionError
Sourcepub fn legacy_to_string(&self) -> String
pub fn legacy_to_string(&self) -> String
Return the implementation of toString to be used inside the VM.
Replacing this with the standard display will break the state root backward compatibility