Module data

Module data 

Extra data that may be sent with the data field of either transaction type.

Structs

ArchivedBlobData
An archived BlobData
ArchivedBlobSidecar
An archived BlobSidecar
ArchivedContractBytecode
An archived ContractBytecode
ArchivedContractCall
An archived ContractCall
ArchivedContractDeploy
An archived ContractDeploy
BlobData
Represents a reference to blob data, including its hash and optional sidecar.
BlobDataResolver
The resolver for an archived BlobData
BlobSidecar
Contains the full contents of a blob, including its KZG commitment and proof.
BlobSidecarResolver
The resolver for an archived BlobSidecar
ContractBytecode
Holds bytes of bytecode and its hash.
ContractBytecodeResolver
The resolver for an archived ContractBytecode
ContractCall
All the data the transfer-contract needs to perform a contract-call.
ContractCallResolver
The resolver for an archived ContractCall
ContractDeploy
Data for performing a contract deployment
ContractDeployResolver
The resolver for an archived ContractDeploy

Enums

ArchivedTransactionData
An archived TransactionData
TransactionData
Data for either contract call or contract deployment.
TransactionDataResolver
The resolver for an archived TransactionData

Constants

MAX_MEMO_SIZE
The maximum size of a memo.

Type Aliases

BlobDataPart
A type alias for the BLOB data part, which consists of 4096 field elements (each 32 bytes), total 128 KiB