Payload

Struct Payload 

pub struct Payload {
    pub chain_id: u8,
    pub sender: PublicKey,
    pub receiver: PublicKey,
    pub value: u64,
    pub deposit: u64,
    pub fee: Fee,
    pub nonce: u64,
    pub data: Option<TransactionData>,
}
The payload for a moonlight transaction.

Fields

chain_id: u8

ID of the chain for this transaction to execute on.

sender: PublicKey

Key of the sender of this transaction.

receiver: PublicKey

Key of the receiver of the funds.

value: u64

Value to be transferred.

deposit: u64

Deposit for a contract.

fee: Fee

Data used to calculate the transaction fee and refund unspent gas.

nonce: u64

Nonce used for replay protection. Moonlight nonces are strictly increasing and incremental, meaning that for a transaction to be valid, only the current nonce + 1 can be used.

The current nonce is queryable via the transfer contract.

data: Option<TransactionData>

Data to do a contract call, deployment, or insert a memo.

Implementations

Source

impl Payload

pub fn to_var_bytes(&self) -> Vec<u8>

Serialize the payload into a byte buffer.

pub fn from_slice(buf: &[u8]) -> Result<Self, BytesError>

Deserialize the payload from bytes slice.

Errors

Errors when the bytes are not canonical.

pub fn signature_message(&self) -> Vec<u8>

Return input bytes to hash the payload.

Note: The result of this function is only meant to be used as an input for hashing and cannot be used to deserialize the payload again.