Fee

Struct Fee 

pub struct Fee {
    pub gas_limit: u64,
    pub gas_price: u64,
    pub stealth_address: StealthAddress,
    pub sender: Sender,
}
The Fee structure

Fields

gas_limit: u64

Gas limit set for a phoenix transaction

gas_price: u64

Gas price set for a phoenix transaction

stealth_address: StealthAddress

Address to send the remainder note

sender: Sender

Sender to use for the remainder

Implementations

Source

impl Fee

pub fn new<R: RngCore + CryptoRng>( rng: &mut R, refund_pk: &PublicKey, gas_limit: u64, gas_price: u64, ) -> Self

Create a new Fee with inner randomness

pub fn deterministic( r: &JubJubScalar, refund_pk: &PublicKey, gas_limit: u64, gas_price: u64, sender_blinder: &[JubJubScalar; 2], ) -> Self

Create a new Fee without inner randomness

pub fn max_fee(&self) -> u64

Calculate the max-fee.

pub fn hash(&self) -> BlsScalar

Return a hash represented by H(gas_limit, gas_price, H([note_pk]))

pub fn gen_remainder_note( &self, gas_consumed: u64, deposit: Option<u64>, ) -> Note

Generates a remainder from the fee and the given gas consumed.

If there is a deposit, it means that the deposit hasn’t been picked up by the contract. In this case, it is added to the remainder note.