pub struct Payload {
pub chain_id: u8,
pub tx_skeleton: TxSkeleton,
pub fee: Fee,
pub data: Option<TransactionData>,
}Expand description
The transaction payload
Fields
chain_id: u8ID of the chain for this transaction to execute on.
tx_skeleton: TxSkeletonTransaction skeleton used for the phoenix transaction.
fee: FeeData used to calculate the transaction fee and refund unspent gas.
data: Option<TransactionData>Data to do a contract call, deployment, or insert a memo.
Implementations
Sourceimpl Payload
impl Payload
Sourcepub fn to_var_bytes(&self) -> Vec<u8>
pub fn to_var_bytes(&self) -> Vec<u8>
Serialize the Payload into a variable length byte buffer.
Sourcepub fn from_slice(buf: &[u8]) -> Result<Self, BytesError>
pub fn from_slice(buf: &[u8]) -> Result<Self, BytesError>
Sourcepub fn to_hash_input_bytes(&self) -> Vec<u8>
pub fn to_hash_input_bytes(&self) -> Vec<u8>
Return input bytes to hash the payload.
Note: The result of this function is only meant to be used as an input
for hashing and cannot be used to deserialize the Payload again.