pub struct StealthAddress { /* private fields */ }Expand description
To obfuscate the identity of the participants, we utilizes a Stealth Address
system.
A StealthAddress is composed by a one-time note-public-key (the actual
address) and a random point R.
Implementations
Sourceimpl StealthAddress
impl StealthAddress
Sourcepub const fn from_raw_unchecked(
R: ExtendedPoint,
note_pk: PublicKey,
) -> StealthAddress
pub const fn from_raw_unchecked( R: ExtendedPoint, note_pk: PublicKey, ) -> StealthAddress
Create a stealth address from its internal parts
A stealth address is intended to be generated as the public counterpart of a one time secret key. If the user opts to generate the stealth address from points, there is no guarantee a secret one time key counterpart will be known, and this stealth address will not provide the required arguments to generate it.
For additional information, check [PublicKey::from_raw_unchecked].
Sourcepub const fn R(&self) -> &ExtendedPoint
pub const fn R(&self) -> &ExtendedPoint
Gets the random point R