pub struct ContractId(/* private fields */);Expand description
ID to identify the wasm contracts after they have been deployed
Implementations
Sourceimpl ContractId
impl ContractId
Sourcepub const fn from_bytes(bytes: [u8; 32]) -> ContractId
pub const fn from_bytes(bytes: [u8; 32]) -> ContractId
Creates a new ContractId from an array of bytes
Sourcepub const fn to_bytes(self) -> [u8; 32]
pub const fn to_bytes(self) -> [u8; 32]
Returns the array of bytes that make up the ContractId
Sourcepub fn as_bytes(&self) -> &[u8]
pub fn as_bytes(&self) -> &[u8]
Returns a reference to the array of bytes that make up the
ContractId
Sourcepub fn as_bytes_mut(&mut self) -> &mut [u8]
pub fn as_bytes_mut(&mut self) -> &mut [u8]
Returns a mutable reference to the array of bytes that make up the
ContractId