Extra data that may be sent with the data field of either transaction
type.
Structs
- Archived
Blob Data - An archived
BlobData - Archived
Blob Sidecar - An archived
BlobSidecar - Archived
Contract Bytecode - An archived
ContractBytecode - Archived
Contract Call - An archived
ContractCall - Archived
Contract Deploy - An archived
ContractDeploy - Blob
Data - Represents a reference to blob data, including its hash and optional sidecar.
- Blob
Data Resolver - The resolver for an archived
BlobData - Blob
Sidecar - Contains the full contents of a blob, including its KZG commitment and proof.
- Blob
Sidecar Resolver - The resolver for an archived
BlobSidecar - Contract
Bytecode - Holds bytes of bytecode and its hash.
- Contract
Bytecode Resolver - The resolver for an archived
ContractBytecode - Contract
Call - All the data the transfer-contract needs to perform a contract-call.
- Contract
Call Resolver - The resolver for an archived
ContractCall - Contract
Deploy - Data for performing a contract deployment
- Contract
Deploy Resolver - The resolver for an archived
ContractDeploy
Enums
- Archived
Transaction Data - An archived
TransactionData - Transaction
Data - Data for either contract call or contract deployment.
- Transaction
Data Resolver - The resolver for an archived
TransactionData
Constants
- MAX_
MEMO_ SIZE - The maximum size of a memo.
Type Aliases
- Blob
Data Part - A type alias for the BLOB data part, which consists of 4096 field elements (each 32 bytes), total 128 KiB